from setuptools import setup, find_packages
from pathlib import Path

# Read the long description from README.md
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name="airis",  # Your package name (must be unique on PyPI)
    version="0.0.0.3",  # Package version
    description="Private Python Package",
    long_description=long_description,
    long_description_content_type="text/markdown",  # Format of README.md
    packages=find_packages(),  # Automatically finds submodules
    include_package_data=True,  # Include non-Python files (like docs)
    install_requires=[
        # List dependencies here, example:
        # "requests>=2.25.1",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",  # Minimum Python version
)
